# hugdatafast
The elegant integration of huggingface/datasets and fastai, and some handy data transformation for huggingface/datasets.

🎓 **Documentation** : https://hugdatafast.readthedocs.io/en/latest/

# Install
`pip install hugdatafast`

# Furture Plan
- I would like to merge this library to fastai and huggingface/datasets respectively. But I may have no time for it. You're welcome to pr this library to the two libraries.

- The implemenatation of `CombineTransform` works but might be too complexed to extend, hope HuggingFace or someone come up with some great ideas.

- Currently, it is designed to work with the dataset part of huggingface/datasets, I may also integrate the part of metric or not.

# Quick Intro
![hugdatafast_fastai](https://user-images.githubusercontent.com/17963619/92091020-be672f00-ee02-11ea-84c0-d54b4855ff4b.png)
